@@ -42,6 +42,21 @@ class UserGet(task_manager.Task):
         return client.keystone_client.users.get(**self.args)
 
 
+class UserAddToGroup(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.users.add_to_group(**self.args)
+
+
+class UserCheckInGroup(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.users.check_in_group(**self.args)
+
+
+class UserRemoveFromGroup(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.users.remove_from_group(**self.args)
+
+
 class ProjectList(task_manager.Task):
     def main(self, client):
         return client._project_manager.list()
@@ -126,6 +141,11 @@ class ServerRebuild(task_manager.Task):
         return client.nova_client.servers.rebuild(**self.args)
 
 
+class HypervisorList(task_manager.Task):
+    def main(self, client):
+        return client.nova_client.hypervisors.list(**self.args)
+
+
 class KeypairList(task_manager.Task):
     def main(self, client):
         return client.nova_client.keypairs.list()
@@ -143,6 +163,7 @@ class KeypairDelete(task_manager.Task):
 
 class NovaUrlGet(task_manager.Task):
     def main(self, client):
+        self.requests = True
         return client.nova_client.client.get(**self.args)
 
 
@@ -261,6 +282,26 @@ class VolumeAttach(task_manager.Task):
         return client.nova_client.volumes.create_server_volume(**self.args)
 
 
+class VolumeSnapshotCreate(task_manager.Task):
+    def main(self, client):
+        return client.cinder_client.volume_snapshots.create(**self.args)
+
+
+class VolumeSnapshotGet(task_manager.Task):
+    def main(self, client):
+        return client.cinder_client.volume_snapshots.get(**self.args)
+
+
+class VolumeSnapshotList(task_manager.Task):
+    def main(self, client):
+        return client.cinder_client.volume_snapshots.list(**self.args)
+
+
+class VolumeSnapshotDelete(task_manager.Task):
+    def main(self, client):
+        return client.cinder_client.volume_snapshots.delete(**self.args)
+
+
 class NeutronSecurityGroupList(task_manager.Task):
     def main(self, client):
         return client.neutron_client.list_security_groups()
@@ -393,7 +434,7 @@ class ContainerUpdate(task_manager.Task):
 
 class ContainerList(task_manager.Task):
     def main(self, client):
-        return client.swift_client.list(**self.args)
+        return client.swift_client.get_account(**self.args)[1]
 
 
 class ObjectCapabilities(task_manager.Task):
@@ -418,7 +459,7 @@ class ObjectUpdate(task_manager.Task):
 
 class ObjectList(task_manager.Task):
     def main(self, client):
-        return client.swift_client.list(**self.args)
+        return client.swift_client.get_container(**self.args)[1]
 
 
 class ObjectMetadata(task_manager.Task):
@@ -583,7 +624,7 @@ class DomainCreate(task_manager.Task):
 
 class DomainList(task_manager.Task):
     def main(self, client):
-        return client.keystone_client.domains.list()
+        return client.keystone_client.domains.list(**self.args)
 
 
 class DomainGet(task_manager.Task):
@@ -601,24 +642,24 @@ class DomainDelete(task_manager.Task):
         return client.keystone_client.domains.delete(**self.args)
 
 
-class ZoneList(task_manager.Task):
+class GroupList(task_manager.Task):
     def main(self, client):
-        return client.designate_client.domains.list()
+        return client.keystone_client.groups.list()
 
 
-class ZoneGet(task_manager.Task):
+class GroupCreate(task_manager.Task):
     def main(self, client):
-        return client.designate_client.domains.get(**self.args)
+        return client.keystone_client.groups.create(**self.args)
 
 
-class RecordList(task_manager.Task):
+class GroupDelete(task_manager.Task):
     def main(self, client):
-        return client.designate_client.records.list(**self.args)
+        return client.keystone_client.groups.delete(**self.args)
 
 
-class RecordGet(task_manager.Task):
+class GroupUpdate(task_manager.Task):
     def main(self, client):
-        return client.designate_client.records.get(**self.args)
+        return client.keystone_client.groups.update(**self.args)
 
 
 class RoleList(task_manager.Task):
